# Python library for extracting multiple open face outcomes

## the code can be run as follows

### python run.py --video_folder_read_path "path to folder with videos" --write_path_file_path "path to write folder with open face outcomes"
